package de.kif.backend

import io.ktor.application.call
import io.ktor.html.respondHtml
import io.ktor.http.content.files
import io.ktor.http.content.static
import io.ktor.routing.get
import io.ktor.routing.routing
import io.ktor.server.engine.embeddedServer
import io.ktor.server.netty.Netty
import kotlinx.html.*
import java.io.File


fun main() {
    embeddedServer(Netty, port = 8080, host = "127.0.0.1") {
        val currentDir = File(".").absoluteFile.canonicalFile

        val webDir = listOf(
            "web",
            "../web"
        ).map {
            File(currentDir, it).canonicalFile
        }.firstOrNull { it.isDirectory }?.absoluteFile ?: error("Can't find 'web' folder!")

        val modules = webDir.list().toList().filter {
            it.endsWith(".js") &&
                    !it.endsWith(".meta.js") &&
                    !it.endsWith("-test.js") &&
                    it != "require.min.js"
        }.joinToString(", ") { "'${it.take(it.length - 3)}'" }

        environment.log.info("Web directory: $webDir")

        routing {
            get("/") {
                call.respondHtml {
                    head {
                        title("KIF Portal")

                        link(href = "/static/style/style.css", type = "text/css", rel = "stylesheet")

                        script(src = "/static/require.min.js") {}

                        script {
                            +"require.config({baseUrl: '/static'});\n"
                            +("require([$modules]);\n")
                        }
                    }
                    body {}
                }
            }
            static("/static") {
                files(webDir)
            }
        }
    }.start(wait = true)
}
